@@ -8,3 +8,6 @@ class RaiseAction(CallAction):
 
     def execute(self):
         raise self.__exception
+
+    def __repr__(self):
+        return f"<RaiseAction: {self.__exception.__class__.__name__}>"
